-- Alternates between which string (though,
-- numbers can be used, too) is returned.
-- Ex: for i = 1,5 do
--       printf("%s ", string.alternate("red", "blue")));
--     end
-- will output: red blue red blue red
--
-- Call again with no parameters [ string.alternate() ]
-- to reset the internal counter
local __alternateCounter = 0;
function string.alternate(...)
	local args = {...};

	if( #args == 0 ) then
		__alternateCounter = 0;
		return;
	end

	__alternateCounter = __alternateCounter + 1;
	if( __alternateCounter > #args ) then
		__alternateCounter = 1;
	end

	return args[__alternateCounter];
end


-- Removes multiple occurances of the provided string.
-- Ex: str = string.reduceMultiples("one/two//three///", "/")
-- Will result in: str = "one/two/three/"
function string.reduceMultiples(str, multStr)
	return string.gsub(str, multStr .. "+", multStr);
end


-- Converts slashes from one type to another.
-- If 'posix' is true, forward slash (/) will be used.
-- Otherwise, back slash (\) will be used.
-- Defaults to forward slash.
function string.fixSlashes(str, posix)
	if( posix == nil ) then posix = true; end;

	if( posix ) then
		str = string.gsub(str, "\\+", "/");
		str = string.gsub(str, "//+", "/");
	else
		str = string.gsub(str, "/+", "\\");
		str = string.gsub(str, "\\+", "\\");
	end

	return str;
end

-- Removes any unnecessary garbage from a
-- full path string, such as any '../',
-- and converts to the desired slash
-- format (if 'posix' is given).
function string.fixPath(str, posix)
	if( posix ~= nil ) then
		if( posix == true ) then
			str = string.fixSlashes(str, true);
			return string.gsub(str, "([%a%d%s%._]+)/../", "");
		else
			str = string.fixSlashes(str, false);
			return string.gsub(str, "([%a%d%s%._]+)\\..\\", "");
		end
	else
		str = string.gsub(str, "([%a%d%s%._]+)/../", "");
		return string.gsub(str, "([%a%d%s%._]+)\\..\\", "");
	end
end

-- Removes extra whitespace
function string.trim(str)
	return string.gsub(str, "^%s*(.-)%s*$", "%1");
end
